View source: R/scale_size_tile.R
| scale_size_tile | R Documentation |
Replacements for ggplot2::scale_size_area() and
ggplot2::scale_size_binned_area() with convenient defaults for
geom_hextile().
scale_size_tile(
name = ggplot2::waiver(),
...,
max_size = 1,
oob = scales::squish
)
scale_size_binned_tile(
name = ggplot2::waiver(),
...,
max_size = 1,
oob = scales::squish
)
name |
The name of the scale. Used as the axis or legend title. If
|
... |
Arguments passed on to |
max_size |
Size of largest points. |
oob |
One of:
|
These are convenience functions with the following changed defaults:
max_size = 1 rather than 6,
oob = scales::squish.
In practice, this makes it easy to set a hard upper limit on a scale, above which sizes are clamped to 1.
A ggplot2::Scale.
library(ggplot2)
d <- ggplot(diamonds, aes(carat, depth, z = price)) +
geom_hextile()
d + scale_size_tile(limits = c(NA, 100))
d + scale_size_binned_tile(transform = "log10")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.